@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: HTTP
-version: 4000.0.9
-id: HTTP-4000.0.9-72969dadf794e36211e8155d286c09d5
+version: 4000.1.1
+id: HTTP-4000.1.1-f00d3e264f070361749d43df3eaa202d
 
 license: BSD3
 copyright: Copyright (c) 2002, Warrick Gray
@@ -12,7 +12,7 @@ copyright: Copyright (c) 2002, Warrick Gray
            Copyright (c) 2004-2005, Dominic Steinitz
            Copyright 2007 Robin Bate Boerop
            Copyright 2008- Sigbjorn Finne
-maintainer: Sigbjorn Finne <sigbjorn.finne@gmail.com>
+maintainer: Ganesh Sittampalam <ganesh@earth.li>
 stability:
 homepage: http://projects.haskell.org/http/
 package-url:
@@ -46,7 +46,7 @@ description: The HTTP package supports client-side web programming in Haskell. I
              >      fmap (take 100) (getResponseBody rsp)
              >
              .
-             Git repository available at <git://code.galois.com/HTTPbis.git>
+             Git repository available at <git://github.com/haskell/HTTP.git>
 category: Network
 author: Warrick Gray <warrick.gray@hotmail.com>
 pkgpath: net/hs-HTTP
@@ -58,25 +58,25 @@ exposed-modules: Network.BufferType Network.Stream
                  Network.HTTP.Proxy Network.HTTP.HandleStream Network.Browser
 hidden-modules: Network.HTTP.Base64 Network.HTTP.MD5
                 Network.HTTP.MD5Aux Network.HTTP.Utils
-import-dirs: /usr/local/lib/ghc/HTTP-4000.0.9
-library-dirs: /usr/local/lib/ghc/HTTP-4000.0.9
-hs-libraries: HSHTTP-4000.0.9
+import-dirs: /usr/local/lib/ghc/HTTP-4000.1.1
+library-dirs: /usr/local/lib/ghc/HTTP-4000.1.1
+hs-libraries: HSHTTP-4000.1.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: array-0.3.0.1-d386e6865e2443d798e250f58dda005d
-         base-3.0.3.2-33c49b5f57a891ca80151e2f4f33f82c
-         bytestring-0.9.1.7-352f069cca85cb3f9e4c06bb76ec4cec
-         mtl-1.1.0.2-9e35d291e0ab20c6aa18823de23bc2de
-         network-2.2.1.7-ef22b259bc7a94db9edff15ac893f74b
-         old-time-1.0.0.5-56dd504e1de073228be3dcc82225ab48
-         parsec-2.1.0.1-bf430163b40c4fad5903c6f59f4237af
+depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
+         base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
+         bytestring-0.9.1.10-2da7b519f76934c0e733bf92c23382ec
+         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
+         network-2.3.0.2-f235f94823d48cc39f2c61444de28400
+         old-time-1.0.0.6-dfdb9c34ec39bc9a2a57345b38e135d4
+         parsec-3.1.1-e9e6a217dbe32c1d9695e23a4f5f794b
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-HTTP-4000.0.9/html/HTTP.haddock
-haddock-html: /usr/local/share/doc/hs-HTTP-4000.0.9/html
+haddock-interfaces: /usr/local/share/doc/hs-HTTP-4000.1.1/html/HTTP.haddock
+haddock-html: /usr/local/share/doc/hs-HTTP-4000.1.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
